---
title: <span class="badge builder"></span> DashboardRegexMapOptions
---
# <span class="badge builder"></span> DashboardRegexMapOptions

## Constructor

```python
DashboardRegexMapOptions()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> dashboard.DashboardRegexMapOptions
```

### <span class="badge object-method"></span> pattern

Regular expression to match against

```python
def pattern(pattern: str) -> typing.Self
```

### <span class="badge object-method"></span> result

Config to apply when the value matches the regex

```python
def result(result: dashboard.ValueMappingResult) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [DashboardRegexMapOptions](./object-DashboardRegexMapOptions.md)
